@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -34,11 +34,14 @@ void MouseGraph::start_polling()
 {
   int x, y;
   Gdk::ModifierType mask;
-  pixmap = Gdk::Pixmap::create
-    (Gdk::Window::get_default_root_window(),
-     Gdk::Display::get_default()->get_default_screen()->get_width(),
-     Gdk::Display::get_default()->get_default_screen()->get_height() );
-  cairo = pixmap->create_cairo_context();
+
+   pixmap = Cairo::ImageSurface::create 
+     (Cairo::FORMAT_ARGB32, 
+      Gdk::Display::get_default()->get_default_screen()->get_width(),
+      Gdk::Display::get_default()->get_default_screen()->get_height());
+
+   cairo = Cairo::Context::create(pixmap);
+
   cairo->set_source_rgb (1.0, 1.0, 1.0);
   cairo->rectangle(0, 0,
                    Gdk::Display::get_default()->get_default_screen()->get_width(),
@@ -56,11 +59,9 @@ void MouseGraph::start_polling()
 
 void MouseGraph::stop_polling()
 {
-  int w= 0, h= 0;
   draw_points();
   cairo.clear();
-  pixmap->get_size(w, h);
-  graphed.emit(Gdk::Pixbuf::create(Glib::RefPtr<Gdk::Drawable>(pixmap), 0, 0, w, h));
+  graphed.emit(pixmap);
   poll_timer.disconnect();
   draw_timer.disconnect();
 }
@@ -176,9 +177,7 @@ bool MouseGraph::is_graphing()
 
 void MouseGraph::graph_it()
 {
-  int w= 0, h= 0;
   draw_points();
-  pixmap->get_size(w, h);
-  graphed.emit(Gdk::Pixbuf::create(Glib::RefPtr<Gdk::Drawable>(pixmap), 0, 0, w, h));
+  graphed.emit(pixmap);
 }
 
