@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -43,12 +43,12 @@ class MouseGraph
     void graph_it();
 
     //signals
-    sigc::signal<void, Glib::RefPtr<Gdk::Pixbuf> > graphed;
+    sigc::signal<void, Cairo::RefPtr<Cairo::ImageSurface> > graphed;
 
  protected:
     MouseGraph();
  private:
-    Glib::RefPtr<Gdk::Pixmap> pixmap;
+    Cairo::RefPtr<Cairo::ImageSurface> pixmap;
     Cairo::RefPtr<Cairo::Context> cairo;
     sigc::connection poll_timer;
     sigc::connection draw_timer;
